@@ -26,6 +26,7 @@ import importlib.resources as pkg_resources
 from concurrent.futures import ProcessPoolExecutor
 from multiprocessing import Manager
 from rich.progress import Progress
+import copy
 
 # 导入mock模块中的函数
 from ketacli.mock.mock_data import mock_data, mock_log, mock_metrics, generate_and_upload
@@ -34,6 +35,9 @@ from ketacli.mock.mock_data import mock_data, mock_log, mock_metrics, generate_a
 from ketacli.sdk.test.cli import test_command
 from ketacli.sdk.test.test_runner import run_test_with_assertion
 
+# 导入AI模块
+from ketacli.sdk.ai import AIClient, AIConfig, ResponseValidator
+
 console = Console()
 
 
@@ -92,6 +96,8 @@ def _list(asset_type, groupId=-1, order="desc", pageNo=1, pageSize=10, prefix=""
         # 解析 url 参数为 dict
         extra_dict = parse_url_params(extra)
 
+    # console.print(f"list {asset_type} with params: {extra_dict}")
+
     def generate_table():
         req = list_assets_request(
             asset_type, groupId, order, pageNo, pageSize, prefix, sort, lang, **extra_dict)
@@ -100,7 +106,6 @@ def _list(asset_type, groupId=-1, order="desc", pageNo=1, pageSize=10, prefix=""
         output_fields = req.get("default_fields", [])
         field_aliases = req.get("field_aliases", {})
         field_converters = req.get("field_converters", {})
-        print(field_aliases)
         if show_all_fields:
             output_fields = []
         if len(fields.strip()) > 0:
@@ -793,6 +798,195 @@ def isearch(page_size=10, limit=500, overflow="ellipsis"):
     except Exception as e:
         console.print_exception()
 
+@command
+def metric(operator="metricGovernance", name=None, id=None, extra=None, page_size=10, page_num=1):
+    """
+    指标操作
+
+    :param operator: 操作类型，如 metricGovernance
+    :param extra: 额外参数，格式为 key=value,key2=value2
+    :param name: 指标名称
+    :param id: 指标 ID
+
+    """
+    assets = []
+    extra_dict = {}
+    if extra is not None:
+        # 解析 url 参数为 dict
+        extra_dict = parse_url_params(extra)
+    if name:
+        req = list_assets_request("metrics", prefix=name, pageSize=page_size, pageNo=page_num)
+        resp = request_get(req["path"], req["query_params"], req["custom_headers"]).json()
+    elif id:
+        metric_info = get_asset_by_id_request(asset_type="metrics", asset_id=id)
+        resp = request_get(metric_info["path"], metric_info["query_params"], metric_info["custom_headers"]).json()
+    elif extra_dict:
+        req = list_assets_request("metrics", pageSize=page_size, pageNo=page_num, **extra_dict)
+        resp = request_get(req["path"], req["query_params"], req["custom_headers"]).json()
+    else:
+        req = list_assets_request("metrics", pageSize=page_size, pageNo=page_num)
+        resp = request_get(req["path"], req["query_params"], req["custom_headers"]).json()
+    if resp:
+        if "items" in resp:
+            assets += resp["items"]
+        else:
+            assets.append(resp)
+
+    if operator == "metricGovernance":
+        _metricsGov(assets)
+
+
+def _metricsGov(assets):
+    """
+    指标治理
+    """
+    prompt = """
+你是一个指标治理专家，负责将未治理的指标进行治理，包括对指标名称进行汉化、添加指标描述、优化指标单位、分类、分组等
+你要接受用户传来的指标信息，修改用户要修修改的字段后返回结果，保持数据结构一致性和完整性。接下来用户会传递json类型的数据，你要处理根据如下要求进行处理。返回数据时保持数据结构与传递时一致。不要包含任何其它非json字符。
+  - 要求：
+    1. 将指标名称(name)翻译为中文
+    2. 添加指标描述(description)信息(描述信息要能够反映该指标的含义、以及指标能够反映出哪些信息等)
+    3. 指标单位(unit)按照附表中《指标单位清单》进行填写
+    4. 指标度量(measureType)按照指标意义选择，可选范围为[COUNTER,GAUGE,HISTOGRAM,SUMMARY]
+    5. 指标类别(category)固定为"None",
+    6. 指标性质(nature)可选：[Normal,Traffic,Error,Performance,Resource]，
+    7. 所有者(owner)固定为空字符串，其它字段不做修改
+  - 指标单位清单：none,short,percent,percentunit,humidity,dB,hex0x,hex,sci,locale,thousand,time,hertz,ns,µs,ms,s,m,h,d,dtdurationms,dtdurations,dthms,timeZh,hertzZh,nsZh,µsZh,msZh,sZh,mZh,hZh,dZh,dtdurationmsZh,dtdurationsZh,dthmsZh,data
+    (IEC),bits,bytes,kbytes,mbytes,gbytes,data rate,pps,bps,Bps,Kbits,KBs,Mbits,MBs,Gbits,GBs,throughput,ops,reqps,rps,wps,iops,opm,rpm,wpm,length,lengthmm,lengthm,lengthft,lengthkm,lengthmi,area,areaM2,areaF2,areaMI2,mass,massmg,massg,masskg,masst,velocity,velocityms,velocitykmh,velocitymph,velocityknot,volume,mlitre,litre,m3,Nm3,dm3,gallons,energy,watt,kwatt,mwatt,Wm2,voltamp,kvoltamp,voltampreact,kvoltampreact,watth,kwatth,kwattm,joule,ev,amp,kamp,mamp,volt,kvolt,mvolt,dBm,ohm,lumens,temperature,celsius,farenheit,kelvin,pressure,pressurembar,pressurebar,pressurekbar,pressurehpa,pressurekpa,pressurehg,pressurepsi,force,forceNm,forcekNm,forceN,forcekN,flow,flowgpm,flowcms,flowcfs,flowcfm,litreh,flowlpm,flowmlpm,angle,degree,radian,grad,acceleration,accMS2,accFS2,accG,radiation,radbq,radci,radgy,radrad,radsv,radrem,radexpckg,radr,radsvh,concentration,ppm,conppb,conngm3,conμgm3,conmgm3,congm3
+    """
+    client = AIClient(system_prompt=prompt)
+    
+    if not assets:
+        console.print("请指定指标名称或 ID", style="red")
+        return
+    
+    # 使用rich进度条显示处理进度
+    with Progress() as progress:
+        task = progress.add_task("[green]处理指标治理...", total=len(assets))
+        
+        for i, asset in enumerate(assets):
+            # 更新进度条描述，显示当前处理的指标
+            asset_name = asset.get('name', f'指标{i+1}')
+            progress.update(task, description=f"[green]正在处理: {asset_name}（{i+1}/{len(assets)}）")
+            
+            # console.print(asset, overflow="fold")
+            asset_id = asset.pop("id")
+            description = asset.get("description", "")
+            if description:
+                progress.advance(task)
+                continue
+
+            # 处理标签
+            _labels = asset.pop("labels", {})
+            labels = [x['key'] for x in _labels]
+            labelList = copy.deepcopy(_labels)
+
+            # 处理分组
+            groupIds = [x.get('id') for x in asset.pop('groups', []) if 'id' in x]
+            asset.update({"labelList": labelList, "labels": labels, 'groupIds': groupIds})
+
+            resp = client.chat(json.dumps(asset))
+            try:
+                asset = json.loads(resp.content)
+            except json.JSONDecodeError:
+                console.print(f"[red]解析AI响应失败: {resp}[/red]")
+                progress.advance(task)
+                continue
+            
+            req_info = update_asset_request(asset_type="metrics", id=asset_id, data=asset)
+            resp = request(req_info["method"], req_info["path"], data=req_info['data']).json()
+            # 推进进度条
+            progress.advance(task)
+
+
+@command
+def ai_chat(message, model=None, stream=False):
+    """与AI大模型进行对话
+    
+    :param message: 要发送给AI的消息
+    :param -m, --model: 指定使用的模型名称
+    :param -s, --stream: 是否使用流式输出
+    """
+    try:
+        client = AIClient(model_name=model)
+        
+        if stream:
+            console.print(f"[bold green]AI ({client.get_current_model()}):[/bold green] ", end="")
+            for chunk in client.stream_chat(message):
+                console.print(chunk, end="")
+            console.print()  # 换行
+        else:
+            response = client.chat(message)
+            console.print(f"[bold green]AI ({response.model}):[/bold green] {response.content}")
+            
+            if response.usage:
+                console.print(f"[dim]Token使用: {response.usage}[/dim]")
+                
+    except Exception as e:
+        console.print(f"[red]AI请求失败: {e}[/red]")
+
+
+@command
+@arg("action", type=str, help="操作类型 (list|add|remove|set-default)", default="list")
+def ai_config(action, model_name=None, endpoint=None, api_key=None):
+    """管理AI模型配置
+    
+    :param action: 操作类型 (list|add|remove|set-default)
+    :param -m, --model-name: 模型名称
+    :param -e, --endpoint: API端点地址
+    :param -k, --api-key: API密钥
+    """
+    try:
+        # 对于add操作，允许空配置；其他操作需要有效配置
+        allow_empty = (action == "add")
+        config = AIConfig(allow_empty=allow_empty)
+        
+        if action == "list":
+            models = config.list_models()
+            default_model = config.get_default_model()
+            
+            console.print("[bold]可用的AI模型:[/bold]")
+            for model in models:
+                marker = " [green](默认)[/green]" if model == default_model else ""
+                console.print(f"  • {model}{marker}")
+                
+        elif action == "add":
+            if not all([model_name, endpoint, api_key]):
+                console.print("[red]添加模型需要提供 --model-name, --endpoint 和 --api-key 参数[/red]")
+                return
+                
+            from ketacli.sdk.ai.config import AIModelConfig
+            model_config = AIModelConfig(
+                name=model_name,
+                endpoint=endpoint,
+                api_key=api_key,
+                model=model_name
+            )
+            config.add_model(model_config)
+            console.print(f"[green]已添加模型: {model_name}[/green]")
+            
+        elif action == "remove":
+            if not model_name:
+                console.print("[red]删除模型需要提供 --model-name 参数[/red]")
+                return
+                
+            config.remove_model(model_name)
+            console.print(f"[green]已删除模型: {model_name}[/green]")
+            
+        elif action == "set-default":
+            if not model_name:
+                console.print("[red]设置默认模型需要提供 --model-name 参数[/red]")
+                return
+                
+            config.set_default_model(model_name)
+            console.print(f"[green]已设置默认模型: {model_name}[/green]")
+            
+        else:
+            console.print("[red]无效的操作类型，支持: list, add, remove, set-default[/red]")
+            
+    except Exception as e:
+        console.print(f"[red]配置操作失败: {e}[/red]")
+
 
 def start():
     # 确保main被正确初始化
